<?php

namespace ProDevign\BlockMeister;

use ProDevign\BlockMeister\Pattern_Builder\BlockMeister_Pattern_Category_Taxonomy;
use ProDevign\BlockMeister\Pattern_Builder\Pattern_Builder;

class Context {

	public static  function is_rest_request(){
		return wp_is_json_request() || ( defined('REST_REQUEST') && REST_REQUEST );
	}

	public static  function is_back_end_screen() {
		return is_admin();
	}

	public static function is_front_end_screen() {
		return ! self::is_back_end_screen() && ! self::is_rest_request();
	}

	/**
	 * Check if the current screen is the list table for blockmeister_pattern post type.
	 * Note: this method can be used even before the global current_screen is available!
	 *
	 * @return bool True if this is the blockmeister_pattern list table, else false
	 */
	public static function is_blockmeister_pattern_list_table_screen() {
		global $pagenow, $plugin_page;
		$is_blockmeister_pattern_list_table = is_admin() &&
		                                      $pagenow === 'edit.php' &&
		                                      is_null( $plugin_page ) &&
		                                      isset( $_GET['post_type'] ) && $_GET['post_type'] === Pattern_Builder::POST_TYPE;

		return $is_blockmeister_pattern_list_table;
	}

	/**
	 * Check if the current screen is the list table for blockmeister_pattern_category taxonomy.
	 * Note: this method can be used even before the global current_screen is available!
	 *
	 * @return bool True if this is the blockmeister_pattern_category list table, else false
	 */
	public static function is_blockmeister_pattern_category_list_table_screen() {
		global $pagenow, $plugin_page;
		$is_blockmeister_pattern_list_table = self::is_back_end_screen() &&
		                                      $pagenow === 'edit-tags.php' &&
		                                      is_null( $plugin_page ) &&
		                                      isset( $_GET['taxonomy'] ) && $_GET['taxonomy'] === BlockMeister_Pattern_Category_Taxonomy::TAXONOMY_NAME;

		return $is_blockmeister_pattern_list_table;
	}

	public static function is_blockmeister_pattern_block_editor() {
		$is_blockmeister_pattern_block_editor = self::is_post_type_block_editor( 'blockmeister_pattern' );
		return $is_blockmeister_pattern_block_editor;
	}


	/**
	 * @return bool True if the current screen is a block editor for any other post type, other than 'blockmeister_pattern', else false.
	 */
	public static function is_other_post_type_block_editor() {
		$is_post_type_block_editor = self::is_post_type_block_editor();
		$is_not_blockmeister_pattern_post_type = ! isset( $_GET["post"] ) || $_GET["post"] !== 'blockmeister_pattern';
		$is_other_post_type_block_editor = $is_post_type_block_editor && $is_not_blockmeister_pattern_post_type;
		return $is_other_post_type_block_editor;
	}


	/**
	 * @param string $post_type Optional post_type to check for. Leave empty to check fro any post_type.
	 *
	 * @return bool True if the current screen is a block editor for any other post type, other than ' blockmeister_patter', else false.
	 */
	public static function is_post_type_block_editor( $post_type = '') {
		global $pagenow;

		if ( ! is_admin() || ! isset( $pagenow ) ) {
			return false;
		}

		$is_new_post_screen = $pagenow === "post-new.php";
		$is_edit_post_screen = $pagenow === "post.php" && isset( $_GET["action"] ) && $_GET['action'] === 'edit';

		if ( ! $is_new_post_screen && ! $is_edit_post_screen ) {
			return false;
		}

		$current_post_type = isset( $_GET["post"] ) ? get_post_type( $_GET["post"] ) : ( $is_new_post_screen ? 'post' : false ); // post-new.php defaults to 'post' for post qs param'

		if ( $current_post_type === false || ( $post_type !== '' && $current_post_type !== $post_type ) ) {
			return false;
		}

		$is_block_editor_enabled_for_current_post_type = self::use_block_editor_for_post_type( $current_post_type );

		return $is_block_editor_enabled_for_current_post_type;
	}

	public static function is_blockmeister_pattern_category_editor() {
		global $pagenow;

		$is_blockmeister_pattern_category_editor =
			is_admin() &&
			isset( $pagenow ) && $pagenow === "term.php" &&
			isset( $_GET["taxonomy"] ) && $_GET['taxonomy'] === 'pattern_category' &&
			isset( $_GET["post_type"] ) && $_GET['post_type'] === 'blockmeister_pattern';

		return $is_blockmeister_pattern_category_editor;
	}

	/**
	 * Return whether the post can be edited in the block editor.
	 *
	 * Note: This is an alternative to the core $current_screen->is_block_editor. But
	 *       this version can also be called in an action admin_init handler when the
	 *       global current_screen is not yet available.
	 *
	 * @return bool Whether the current post is or can be edited in the block editor.
	 */
	public static function is_block_editor() {

		global $current_screen, $post;

		if ( $current_screen ) {
			return $current_screen->is_block_editor;
		}

		$is_block_editor = false;

		/** This filter is documented in wp-admin/post.php */
		$replace_editor = apply_filters( 'replace_editor', false, $post );

		if ( ! $replace_editor ) {
			$is_block_editor = function_exists('use_block_editor_for_post') && use_block_editor_for_post( $post );
		}

		return $is_block_editor;
	}

	public static function is_site_editor() {

		global $current_screen, $pagenow;

		$is_site_editor = $pagenow === "site-editor.php" || // true in WP 5.9
		                  $pagenow === "themes.php" && $current_screen && $current_screen->id === "appearance_page_gutenberg-edit-site"; // true in WP 6.x
		return $is_site_editor;

	}

	/**
	 * Return whether a post type is set to be edited with the block editor.
	 *
	 * The block editor depends on the REST API, and if the post type is not shown in the
	 * REST API, then it won't work with the block editor.
	 *
	 * Note: This method is a copy of post.php::use_block_editor_for_post_type.
	 * The reason we replicated it here is the original seems to be not
	 * yet loaded at the point we need it.
	 * Since WP 5.9 | Block Meister 3.0.4 this line has been replaced by a true return
	 *   else this was leading to not yet exising/loaded code:
	 *   apply_filters( 'use_block_editor_for_post_type', true, $post_type ); line
	 *
	 * @param string $post_type The post type.
	 * @return bool Whether the post type can be edited with the block editor.
	 */
	private static function use_block_editor_for_post_type( $post_type ) {

		if ( ! post_type_exists( $post_type ) ) {
			return false;
		}

		if ( ! post_type_supports( $post_type, 'editor' ) ) {
			return false;
		}

		$post_type_object = get_post_type_object( $post_type );
		if ( $post_type_object && ! $post_type_object->show_in_rest ) {
			return false;
		}

		return true; // note: in WP original code this was filtered but that lead to an error (cause core code was not yet loaded)
	}

}