<?php

namespace ProDevign\BlockMeister\Pattern_Builder;

/**
 * Defines and registers Custom taxonomy for post type: 'blockmeister_pattern'
 */
class BlockMeister_Pattern_Category_Taxonomy {

	const TAXONOMY_NAME = 'pattern_category';

	public function __construct() {
	}

	public function init() {
		// Init with a high priority so other plugins/theme can register there block pattern categories first.
		// Note: if in future an even higher prio is set, remember to increase the priority of Block_Pattern_Registry->init() too!
		add_action( 'init', [ $this, 'register_blockmeister_pattern_category_taxonomy' ], 1001 );
		add_action( 'init', [ $this, 'register_custom_pattern_categories' ], 1001 );
	}

	public function register_blockmeister_pattern_category_taxonomy() {

		$capabilities = [
			'manage_terms' => 'manage_blockmeister_pattern_category',
			'edit_terms'   => 'manage_blockmeister_pattern_category',
			'delete_terms' => 'manage_blockmeister_pattern_category',
			'assign_terms' => 'edit_blockmeister_patterns',
		];

		$args = array(
			'default_term'      => [
				'name'        => esc_html__( 'Default', 'blockmeister' ),
				// will be set after registration, this is to prevent multiple terms when site name is changed
				'slug'        => 'default',
				'description' => esc_html__( 'Default category', 'blockmeister' ),
			], // see: https://core.trac.wordpress.org/ticket/43517
			'hierarchical'      => true,
			'public'            => false,
			'show_ui'           => true,
			'show_admin_column' => true,
			'show_in_nav_menus' => false,
			'show_tagcloud'     => false,
			'show_in_rest'      => true,
			'capabilities'      => $capabilities,
		);

		register_taxonomy( self::TAXONOMY_NAME, 'blockmeister_pattern', $args );

		// set current site name as name for the default term. This handles also when the site name is changed by the user.
		$site_name    = esc_html( get_bloginfo( 'name' ) );
		$default_term = get_term_by( 'slug', 'default', self::TAXONOMY_NAME );

		if ( $site_name !== $default_term->name) {
			wp_update_term( $default_term->term_id, self::TAXONOMY_NAME, [	'name' => $site_name ] );
		}

	}

	/**
	 * Register all custom pattern categories (for use in block editor)
	 */
	public function register_custom_pattern_categories() {

		$wp_pattern_category_registry  = \WP_Block_Pattern_Categories_Registry::get_instance();

		$pattern_category_terms = get_terms( array(
			'taxonomy'   => self::TAXONOMY_NAME,
			'hide_empty' => false,
		) );

		// Register (using register_block_pattern_category) all custom pattern_category terms
		foreach ( $pattern_category_terms as $pattern_category_term ) {
			if ( ! $wp_pattern_category_registry->is_registered( $pattern_category_term->slug ) ) {
				register_block_pattern_category(
					sanitize_title( $pattern_category_term->slug ),
					[ 'label' => sanitize_textarea_field( $pattern_category_term->name ) ]
				);
			}
		}
	}




}
